summaryrefslogtreecommitdiffstats
path: root/src/notedrag.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/notedrag.h')
-rw-r--r--src/notedrag.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/notedrag.h b/src/notedrag.h
index 804d05d..eeff237 100644
--- a/src/notedrag.h
+++ b/src/notedrag.h
@@ -87,7 +87,7 @@ class ExtendedTextDrag : public TQTextDrag
static bool decode(const TQMimeSource *e, TQString &str, TQCString &subtype);
};
// Support KDE 3.3 and older PROTECTED KURLDrag::encodedData()!
#include <kurldrag.h>
class KURLDrag2 : public KURLDrag
@@ -96,9 +96,9 @@ class KURLDrag2 : public KURLDrag
TQ_OBJECT
public:
KURLDrag2(const KURL::List &urls) : KURLDrag(urls) {}
- TQByteArray encodedData2(const char *mime) const
+ TQByteArray tqencodedData2(const char *mime) const
{
- return encodedData(mime);
+ return tqencodedData(mime);
}
};
@@ -87,7 +87,7 @@ class ExtendedTextDrag : public TQTextDrag
static bool decode(const TQMimeSource *e, TQString &str, TQCString &subtype);
};
-// Support KDE 3.3 and older PROTECTED KURLDrag::encodedData()!
+// Support KDE 3.3 and older PROTECTED KURLDrag::tqencodedData()!
#include <kurldrag.h>
class KURLDrag2 : public KURLDrag